#[unsafe(no_mangle)]pub unsafe extern "C" fn instrument_cmp(
drcontext: *mut c_void,
instrlist: *mut instrlist_t,
instr: *mut instr_t,
) -> dr_emit_flags_tExpand description
The instrumentation applied to a CMP or TEST instruction: The instruction operands may be registers, immediates, or memory references (or any combination). The correct instrumentation must be added (conditional on the operand types) to load the operand values into two scratch registers. These scratch registers are then passed as arguments to a clean call that does a byte-by-byte comparison and writes coverage information to the AFL bitmap.